## What it is

Debian base package to notify installation of new packages outside the control of salt.

## Installation
This script depends on python package, so python3 should be installed on the machine

- The 99dpkgnotify file must be installed in /etc/apt/apt.conf.d/99dpkgnotify
- The dpkgnotify file must be installed in /usr/bin/dpkgnotify
